pub struct TurboMalloc;Expand description
Turbo’s preferred global allocator. This is a new type instead of a type alias because you can’t use type aliases to instantiate unit types (E0423).
Implementations
Sourceimpl TurboMalloc
impl TurboMalloc
pub fn memory_usage() -> usize
pub fn thread_stop()
pub fn thread_park()
pub fn allocation_counters() -> AllocationCounters
pub fn reset_allocation_counters(start: AllocationCounters)
Sourcepub fn memory_pressure() -> Option<u8>
pub fn memory_pressure() -> Option<u8>
Returns a memory pressure value in the range 0..=100, or None when
the current platform does not expose a memory pressure signal or a
query for it failed.
0 means no memory pressure, 100 means maximum pressure.
- On Linux this is derived from
/proc/pressure/memory(thesomeavg10stall percentage), falling back to(MemTotal - MemAvailable) / MemTotalfrom/proc/meminfowhen PSI is not available (older kernels, noCONFIG_PSI, or containers without access). - On macOS this is derived from the
kern.memorystatus_levelsysctl (100 - free_memory_percentage). - On Windows this is
MEMORYSTATUSEX::dwMemoryLoad(percentage of physical memory in use). - On other platforms this returns
None.